==> 1.0.95+1.tar.gz: lib/props/StandardScreenResponse.dart <==
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/standard_page_response_entity.g.dart';
//import 'package:json_annotation/json_annotation.dart';
import "dart:async";

part 'StandardScreenResponse.g.dart';

//step -1 APIRESponse
//getLogin Api in lokal app
//handle api in lokal app login screen

@RestApi(baseUrl: "https://demo2451720.mockable.io")
abstract class ApiClient {
  factory ApiClient(Dio dio, {String? baseUrl}) = _ApiClient;

  @GET('/MainPageOne')
  Future<StandardScreenResponse> getUsers();

  @GET('/MainPageTwo')
  Future<StandardScreenResponse> getUsers2();
}

@JsonSerializable()
class StandardScreenResponse {
  late String type;
  late String componentStype;
  // late String? pullToRefresh;
  late Map<String, dynamic>? pageState;
  late Map<String, dynamic>? headers = null;
  late Map<String, dynamic>? footers = null;
  late List<StandardPageResponseWidgets> widgets;
  // late StandardPageResponseDataStore dataStore;
  late Map<String, dynamic>? dataStore;
  StandardScreenResponse();
  factory StandardScreenResponse.fromJson(Map<String, dynamic> json) =>
      $StandardPageResponseEntityFromJson(json);

  Map<String, dynamic> toJson() => $StandardPageResponseEntityToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseWidgets {
  late String id;
  late String uiType;

  StandardPageResponseWidgets();

  factory StandardPageResponseWidgets.fromJson(Map<String, dynamic> json) =>
      $StandardPageResponseWidgetsFromJson(json);

  Map<String, dynamic> toJson() => $StandardPageResponseWidgetsToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleText {
  late String id;
  late String text;
  late StandardPageResponseDataStoreTitleTextAction action;

  StandardPageResponseDataStoreTitleText();

  factory StandardPageResponseDataStoreTitleText.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextAction {
  late StandardPageResponseDataStoreTitleTextActionTap tap;

  StandardPageResponseDataStoreTitleTextAction();

  factory StandardPageResponseDataStoreTitleTextAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextActionTap {
  late String type;
  late StandardPageResponseDataStoreTitleTextActionTapData data;

  StandardPageResponseDataStoreTitleTextActionTap();

  factory StandardPageResponseDataStoreTitleTextActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextActionTapData {
  late String url;

  StandardPageResponseDataStoreTitleTextActionTapData();

  factory StandardPageResponseDataStoreTitleTextActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButton {
  late String id;
  late String text;
  late StandardPageResponseDataStoreTitleButtonAction action;

  StandardPageResponseDataStoreTitleButton();

  factory StandardPageResponseDataStoreTitleButton.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonAction {
  late StandardPageResponseDataStoreTitleButtonActionTap tap;

  StandardPageResponseDataStoreTitleButtonAction();

  factory StandardPageResponseDataStoreTitleButtonAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonActionTap {
  late String type;
  late StandardPageResponseDataStoreTitleButtonActionTapData data;

  StandardPageResponseDataStoreTitleButtonActionTap();

  factory StandardPageResponseDataStoreTitleButtonActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonActionTapData {
  late String url;

  StandardPageResponseDataStoreTitleButtonActionTapData();

  factory StandardPageResponseDataStoreTitleButtonActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadline {
  late String id;
  late String src;
  late StandardPageResponseDataStoreImageHeadlineAction action;

  StandardPageResponseDataStoreImageHeadline();

  factory StandardPageResponseDataStoreImageHeadline.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineAction {
  late StandardPageResponseDataStoreImageHeadlineActionTap tap;

  StandardPageResponseDataStoreImageHeadlineAction();

  factory StandardPageResponseDataStoreImageHeadlineAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineActionTap {
  late String type;
  late StandardPageResponseDataStoreImageHeadlineActionTapData data;

  StandardPageResponseDataStoreImageHeadlineActionTap();

  factory StandardPageResponseDataStoreImageHeadlineActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineActionTapData {
  late String url;

  StandardPageResponseDataStoreImageHeadlineActionTapData();

  factory StandardPageResponseDataStoreImageHeadlineActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

==> 1.0.104+1.tar.gz: lib/props/StandardScreenResponse.dart <==
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:retrofit/retrofit.dart';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/standard_page_response_entity.g.dart';
//import 'package:json_annotation/json_annotation.dart';
import "dart:async";

import '../Renderer.dart';
import '../components/UikWidget.dart';

part 'StandardScreenResponse.g.dart';

//step -1 APIRESponse
//getLogin Api in lokal app
//handle api in lokal app login screen

@RestApi(baseUrl: "https://demo2451720.mockable.io")
abstract class ApiClient {
  factory ApiClient(Dio dio, {String? baseUrl}) = _ApiClient;

  @GET('/MainPageOne')
  Future<StandardScreenResponse> getUsers();

  @GET('/MainPageTwo')
  Future<StandardScreenResponse> getUsers2();
}

@JsonSerializable()
class StandardScreenResponse {
  late String type;
  late String componentStype;
  late Map<String, dynamic>? pageState;
  late Map<String, dynamic>? headers = null;
  late Map<String, dynamic>? footers = null;
  late List<StandardPageResponseWidgets> widgets;
  // late StandardPageResponseDataStore dataStore;
  late Map<String, dynamic>? dataStore = null;
  StandardScreenResponse();

  factory StandardScreenResponse.fromJson(Map<String, dynamic> json) =>
      $StandardPageResponseEntityFromJson(json);

  Map<String, dynamic> toJson() => $StandardPageResponseEntityToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseWidgets {
  late String id;
  late String uiType;

  StandardPageResponseWidgets();

  factory StandardPageResponseWidgets.fromJson(Map<String, dynamic> json) =>
      $StandardPageResponseWidgetsFromJson(json);

  Map<String, dynamic> toJson() => $StandardPageResponseWidgetsToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleText {
  late String id;
  late String text;
  late StandardPageResponseDataStoreTitleTextAction action;

  StandardPageResponseDataStoreTitleText();

  factory StandardPageResponseDataStoreTitleText.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextAction {
  late StandardPageResponseDataStoreTitleTextActionTap tap;

  StandardPageResponseDataStoreTitleTextAction();

  factory StandardPageResponseDataStoreTitleTextAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextActionTap {
  late String type;
  late StandardPageResponseDataStoreTitleTextActionTapData data;

  StandardPageResponseDataStoreTitleTextActionTap();

  factory StandardPageResponseDataStoreTitleTextActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleTextActionTapData {
  late String url;

  StandardPageResponseDataStoreTitleTextActionTapData();

  factory StandardPageResponseDataStoreTitleTextActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleTextActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleTextActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButton {
  late String id;
  late String text;
  late StandardPageResponseDataStoreTitleButtonAction action;

  StandardPageResponseDataStoreTitleButton();

  factory StandardPageResponseDataStoreTitleButton.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonAction {
  late StandardPageResponseDataStoreTitleButtonActionTap tap;

  StandardPageResponseDataStoreTitleButtonAction();

  factory StandardPageResponseDataStoreTitleButtonAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonActionTap {
  late String type;
  late StandardPageResponseDataStoreTitleButtonActionTapData data;

  StandardPageResponseDataStoreTitleButtonActionTap();

  factory StandardPageResponseDataStoreTitleButtonActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreTitleButtonActionTapData {
  late String url;

  StandardPageResponseDataStoreTitleButtonActionTapData();

  factory StandardPageResponseDataStoreTitleButtonActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreTitleButtonActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreTitleButtonActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadline {
  late String id;
  late String src;
  late StandardPageResponseDataStoreImageHeadlineAction action;

  StandardPageResponseDataStoreImageHeadline();

  factory StandardPageResponseDataStoreImageHeadline.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineAction {
  late StandardPageResponseDataStoreImageHeadlineActionTap tap;

  StandardPageResponseDataStoreImageHeadlineAction();

  factory StandardPageResponseDataStoreImageHeadlineAction.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineActionTap {
  late String type;
  late StandardPageResponseDataStoreImageHeadlineActionTapData data;

  StandardPageResponseDataStoreImageHeadlineActionTap();

  factory StandardPageResponseDataStoreImageHeadlineActionTap.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionTapFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionTapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class StandardPageResponseDataStoreImageHeadlineActionTapData {
  late String url;

  StandardPageResponseDataStoreImageHeadlineActionTapData();

  factory StandardPageResponseDataStoreImageHeadlineActionTapData.fromJson(
          Map<String, dynamic> json) =>
      $StandardPageResponseDataStoreImageHeadlineActionTapDataFromJson(json);

  Map<String, dynamic> toJson() =>
      $StandardPageResponseDataStoreImageHeadlineActionTapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}
